## PyTraffic -- A python simulation of the game Rush Hour invented by
## Nob Yoshigahara and commercialized by Binary Arts Corporation.
##
## Copyright (C) 2001-2005 Michel Van den Bergh <michel.vandenbergh@uhasselt.be>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING.
## If not, write to the Free Software Foundation, Inc.,
## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
##

import os
import Misc
import ThemeEngine
import SoundData

np=Misc.normalize_path


# SoundServer is a singleton object!


class SoundServer:

    def __init__(self,theme_engine):
        self.__sound_output_explicitly_set=0
        self.theme_engine=theme_engine

    def last_error(self):
        return self.__last_error

    def sound_works(self):
        return self.__sound_works
          
    def start_music(self):
        if self.__sound_works and not self.mixer.music.get_busy():
            self.mixer.music.play(-1)
            self.__music_playing=1

    def stop_music(self):
        if self.__sound_works and self.mixer.music.get_busy():
            self.mixer.music.stop()
            self.__music_playing=0

    def music_playing(self):
        return self.__music_playing

    def enable_sound(self):
        if self.__sound_works:
            self.__sound_enabled=1

    def disable_sound(self):
        self.__sound_enabled=0

    def sound_enabled(self):
        return self.__sound_enabled
            

    def play(self,sound):
        if self.__sound_works and self.__sound_enabled and sound!=None:
            sound.play()
        

    def sound_has_worked(self):
        return self.__sound_has_worked

    def setsoundoutput(self,output):
        self.__output=output
        self.__sound_output_explicitly_set=1

    def getsoundoutput(self):
        return self.__output

    def default_bag(self,propertybag):
        propertybag['sound_has_worked']=1
        propertybag['sound_output']='Default'
        propertybag['music_playing']=1
        propertybag['sound_enabled']=1

    def load_bag(self,propertybag):
        self.__output=output=propertybag['sound_output']
        SoundData.do_os_stuff(output)
        self.__sound_works=0
        self.__sound_enabled=0
        self.__music_playing=0
        try:
            import pygame.mixer
            self.mixer=pygame.mixer
            self.mixer.init()
            self.mixer.music.load(self.theme_engine.find_music(\
                                                     "Ranger_Song.s3m"))
	    dummy_test=self.mixer.Sound(self.theme_engine.find_sound(\
                name='applause',theme='DeLuxe3D'))
            self.__sound_works=1
        except Exception,e:
            self.__last_error=str(e)


        self.__sound_has_worked=propertybag['sound_has_worked']
        if self.__sound_has_worked and self.__sound_works:
            if propertybag['music_playing']:
                self.start_music()
            if propertybag['sound_enabled']:
                self.enable_sound()
        elif self.__sound_works:
            self.start_music()
            self.enable_sound()
            
        

    def save_bag(self,propertybag):
        propertybag['music_playing']=self.__music_playing
        propertybag['sound_enabled']=self.__sound_enabled
        if not self.__sound_output_explicitly_set:
            propertybag['sound_has_worked']=self.__sound_works
        else:
            propertybag['sound_has_worked']=1 # force dialog box after restart
            propertybag['music_playing']=1  # if sound does not work, otherwise
            propertybag['sound_enabled']=1  # enable sound

        propertybag['sound_output']=self.__output
