#!/usr/bin/python
## PyTraffic -- A python simulation of the game Rush Hour invented by
## Nob Yoshigahara and commercialized by Binary Arts Corporation.
##
## Copyright (C) 2001-2005 Michel Van den Bergh <michel.vandenbergh@uhasselt.be>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING.
## If not, write to the Free Software Foundation, Inc.,
## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
##

import os
import Misc
import gtk
import SmartLabel

np=Misc.normalize_path

class StatisticsDialog(gtk.Window):
    def __init__(self,parent=None):
        gtk.Window.__init__(self,gtk.WINDOW_TOPLEVEL)
	self.set_icon_from_file(np("ICNS/carNred64x64.png"))
        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
        self.set_destroy_with_parent(True)
	# transient does not work well on nt
        if parent and os.name!='nt':
	        self.set_transient_for(parent)
        self.set_resizable(False)
        self.set_title("PyTraffic Statistics")
        self.connect("delete_event",self.hide)
        ff=self.ff=gtk.Frame("Statistics")
        ff.set_border_width(5)
        self.add(ff)
        f=self.f=gtk.Table(rows=5,columns=3,homogeneous=False)
        f.set_border_width(5)
        ff.add(f)
        heading_difficulty=SmartLabel.SmartLabel('')
        heading_difficulty.set_char_width(10)
        heading_difficulty.set_anchor('e')
        heading_solved=SmartLabel.SmartLabel('Solved')
        heading_solved.set_char_width(8)
        heading_solved.set_anchor('e')
        heading_total=SmartLabel.SmartLabel('Total')
        heading_total.set_char_width(8)
        heading_total.set_anchor('e')
        trivial=SmartLabel.SmartLabel('Trivial')
        trivial.set_anchor('w')
        easy=SmartLabel.SmartLabel('Easy')
        easy.set_anchor('w')
        intermediate=SmartLabel.SmartLabel('Intermediate')
        intermediate.set_anchor('w')
        advanced=SmartLabel.SmartLabel('Advanced')
        advanced.set_anchor('w')
        expert=SmartLabel.SmartLabel('Expert')
        expert.set_anchor('w')
        no_statistics_message='(no statistics)'
        trivial_message=SmartLabel.SmartLabel(no_statistics_message)
        trivial_message.set_anchor('e')
        trivial_message.set_sensitive(False)
        easy_message=SmartLabel.SmartLabel(no_statistics_message)
        easy_message.set_sensitive(False)
        easy_message.set_anchor('e')
        self.intermediate_solved=SmartLabel.SmartLabel()
        self.intermediate_solved.set_anchor('e')
        self.intermediate_total=SmartLabel.SmartLabel()
        self.intermediate_total.set_anchor('e')
        self.advanced_solved=SmartLabel.SmartLabel()
        self.advanced_solved.set_anchor('e')
        self.advanced_total=SmartLabel.SmartLabel()
        self.advanced_total.set_anchor('e')
        self.expert_solved=SmartLabel.SmartLabel()
        self.expert_solved.set_anchor('e')
        self.expert_total=SmartLabel.SmartLabel()
        self.expert_total.set_anchor('e')

        f.attach(heading_difficulty,0,1,0,1)
        f.attach(heading_solved,1,2,0,1)
        f.attach(heading_total,2,3,0,1)
        
        f.attach(trivial,0,1,1,2)
        f.attach(easy,0,1,2,3)
        f.attach(intermediate,0,1,3,4)
        f.attach(advanced,0,1,4,5)
        f.attach(expert,0,1,5,6)

        f.attach(trivial_message,1,3,1,2)
        f.attach(easy_message,1,3,2,3)

        f.attach(self.intermediate_solved,1,2,3,4)
        f.attach(self.intermediate_total,2,3,3,4)

        f.attach(self.advanced_solved,1,2,4,5)
        f.attach(self.advanced_total,2,3,4,5)

        f.attach(self.expert_solved,1,2,5,6)
        f.attach(self.expert_total,2,3,5,6)
        
    def show(self):
        self.show_all()
        self._visible=1

    def hide(self,*args):
	gtk.Window.hide_all(self)
        self.unrealize()
        self._visible=0
        
    def save_bag(self,propertybag):
        propertybag['statistics']=self._visible

    def default_bag(self,propertybag):
        propertybag['statistics']=0

    def load_bag(self,propertybag):
        self.visible=propertybag['statistics']
        if self.visible:
            self.show()
        else:
            self.hide()

    def update_statistics(self,statistics):
        self.intermediate_solved.set_text(
            str(statistics['Intermediate']['Solved']))
        self.intermediate_total.set_text(
            str(statistics['Intermediate']['Total']))

        self.advanced_solved.set_text(
            str(statistics['Advanced']['Solved']))
        self.advanced_total.set_text(
            str(statistics['Advanced']['Total']))

        self.expert_solved.set_text(
            str(statistics['Expert']['Solved']))
        self.expert_total.set_text(str(statistics['Expert']['Total']))

        
