## PyTraffic -- A python simulation of the game Rush Hour invented by
## Nob Yoshigahara and commercialized by Binary Arts Corporation.
##
## Copyright (C) 2001-2005 Michel Van den Bergh <michel.vandenbergh@uhasselt.be>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING.
## If not, write to the Free Software Foundation, Inc.,
## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
##

import Misc
import Affine2D
import os
import glob

np=Misc.normalize_path

def get_id(path):
    name=os.path.split(path)[1]
    base=os.path.splitext(name)[0]
    iid=base[6:]
    return iid

def get_ids(list_of_paths):
    return map(get_id,list_of_paths)

def get_background_ids(list_of_paths):
    return map(lambda x: os.path.splitext(os.path.split(x)[1])[0],list_of_paths)

class NoSuchTheme(Exception):
    pass

class ThemeEngine:

    def theme_has_sound(self):
    	return os.path.exists(np(os.path.join("THEMES",
                                              self.current_theme,
                                              "SOUND")))

    def find_sound(self,name,theme=None):
        if not theme:
            theme=self.current_theme
        return np(os.path.join("THEMES",
                                theme,
                                "SOUND",
                                name+".ogg"))

    def find_music(self,name):
        return np(os.path.join("MUSIC",name))

# world to screen transform
    def find_transform(self):
        return np(os.path.join("THEMES",self.current_theme,"transform"))

    def find_background_basepoints(self):
        return np(os.path.join("THEMES",
                               self.current_theme,
                               "BACKGROUND",
                               "basepoints"))
    
    def find_car_basepoints(self):
        return np(os.path.join("THEMES",
                               self.current_theme,
                               "CARS",
                               "basepoints"))
    
    def __find_car_image(self,name,theme=None):
        if not theme:
            theme=self.current_theme
        return np(os.path.join("THEMES",
                               theme,
                               "CARS",
                               name+".png"))
    
    def find_car_image(self,horizontal,truck,type,theme=None):
        T=['C','T']
        H=['V','H']
        if type=='red':
            return self.__find_car_image('carNred',theme)
        else:
            return self.__find_car_image('car'+H[horizontal]+T[truck]\
                                       +'N'+type,theme)
    

    def find_background(self,name,theme=None):
        if not theme:
            theme=self.current_theme
        return np(os.path.join("THEMES",
                               theme,
                               "BACKGROUND",
                               name+".png"))

    def load_bag(self,propertybag):
        self.settheme(propertybag['current_theme'])

    def save_bag(self,propertybag):	       
        propertybag['current_theme']=self.current_theme

    def default_bag(self,propertybag):
        propertybag['current_theme']='DeLuxe3D'
    	     	
    def settheme(self,theme):
        if theme not in self.getavailable_themes():
            self.current_theme='DeLuxe3D'
        else:
            self.current_theme=theme

    def gettheme(self):
        return self.current_theme

    def getavailable_themes(self):
        np=Misc.normalize_path
        themelist=map(lambda x: os.path.split(x)[1],
                           glob.glob(np(os.path.join("THEMES","*"))))
        themelist.sort()
        return themelist

    def gettrucks(self):
        return get_ids(glob.glob(self.__find_car_image("carHTN*")))

    def getcars(self):
        return get_ids(glob.glob(self.__find_car_image("carHCN*")))

    def getbackgrounds(self):
        return  get_background_ids(\
            glob.glob(self.find_background('*')))

           
