#!/usr/bin/python

## PyTraffic -- A python simulation of the game Rush Hour invented by
## Nob Yoshigahara and commercialized by Binary Arts Corporation.
##
## Copyright (C) 2001-2005 Michel Van den Bergh <michel.vandenbergh@uhasselt.be>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING.
## If not, write to the Free Software Foundation, Inc.,
## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
##



import version 
import os,glob,sys,string

from distutils.core import setup, Extension


py2exe_present=1
try:
    import py2exe
except ImportError:
    py2exe_present=0
    print "No py2exe :-("



# Terrible hack: peek at prefix...
# The only way I know how to acces the prefix, is by redefining the install
# command, which seems overkill....
#
# The problem is that the files
# pytraffic.desktop and pytraffic
# are installed outside the installation directory <prefix>/share/pytraffic2.
# Furthermore both their location and content depend on <prefix>.
# Distutils should really have a 'configure' step.
if os.name=='posix':
    prefix='/usr/local'
    for arg_index in xrange(1,len(sys.argv)):
        arg=sys.argv[arg_index]
        if arg=='--prefix':
            if arg_index!=len(sys.argv)-1:
                prefix=sys.argv[arg_index+1]
                break
        elif arg[0:9]=='--prefix=':
            prefix=arg[9:]
            break
    prefix=os.path.abspath(prefix)
    print "prefix=%s" % prefix


options={}
options['sdist']={'formats':'gztar'}


if os.name=='nt':
    options['install']={'prefix': "c:\\"+version.install_leaf, 
                        'install_lib' :  "c:\\"+version.install_leaf}
    options['build_ext']={'compiler' : 'mingw32'}
else:
    options['install']={'prefix' : prefix,
                       'install_lib' : '$base/share/'+version.install_leaf,
                       'install_data' : '$base/share/'+version.install_leaf}
    options['build_ext']={'compiler' : 'unix'}

if py2exe_present:
	options['py2exe']={
        "includes": "pango,atk,gobject",
     }


# We now construct the files pytraffic and pytraffic.desktop. We will
# remove them afterwards.
if os.name=='posix':
    main_command_contents=r"""exec python %s/share/%s/Main.py 
""" % (prefix,version.install_leaf)

    main_command_file=open("pytraffic","w")
    main_command_file.write(main_command_contents)
    main_command_file.close()

    os.chmod("pytraffic",0755)

    menu_entry_contents=r"""[Desktop Entry]
Encoding=UTF-8
Categories=Application;Game;
X-Desktop-File-Install-Version=0.2
Name=PyTraffic
Description=A Python version of the board game Rush Hour created by Binary Arts Coporation.
Exec=%s/bin/pytraffic
Terminal=0
Type=Application
Icon=%s/share/%s/ICNS/carNred64x64.png
""" % (prefix,prefix,version.install_leaf)

    menu_entry_file=open("pytraffic.desktop","w")
    menu_entry_file.write(menu_entry_contents)
    menu_entry_file.close()


def main_command():
    if os.name=='posix':
        return [(prefix+"/bin",['pytraffic'])]
    else:
        return [(".",["WinMain.pyw"])]

def windows_installer():
    if os.name=='nt':
        return [("Inno",['Inno/PyTraffic.iss','Inno/PyTrafficFull.iss'])]
    else:
        return []

def menu_entry():
    if os.name=='posix':
        return [(prefix+"/share/applications",["pytraffic.desktop"])]
    else:
        return []

themes=version.themes

def theme_files():
    result=[]
    for t in themes:
        files=[('THEMES/%s' % t, glob.glob('THEMES/%s/transform' % t)),
               ('THEMES/%s/CARS' % t, glob.glob('THEMES/%s/CARS/*.png' % t)),
               ('THEMES/%s/CARS' % t, glob.glob('THEMES/%s/CARS/basepoints' % t)),
               ('THEMES/%s/BACKGROUND' % t, glob.glob('THEMES/%s/BACKGROUND/*.png' % t)),
               ('THEMES/%s/BACKGROUND' % t, glob.glob('THEMES/%s/BACKGROUND/basepoints' % t))
               ]
        if glob.glob('THEMES/%s/SOUND/*.ogg' % t):
            files+=[('THEMES/%s/SOUND' % t, glob.glob('THEMES/%s/SOUND/*.ogg' % t))]
        result+=files
    return result




py_modules=['Affine2D',
                  'Arena',
                  'ArtWork',
	          'BottomBar',
                  'Board',
                  'Cache',
		  'Canvas',
                  'Chooser',
                  'CondMessageBox',
                  'Game',
                  'GameState',
                  'Hint',
                  'History',
                  'ImageCache',
                  'LevelFileParser',
                  'LevelSelector',
                  'Misc',
		  'PropertyBag',
		  'ShowHTML',
                  'SmartLabel',
                  'SoundCache',
                  'SoundData',
                  'SoundServer',
                  'ThemeEngine',
                  'Timer',
		  'StatisticsDialog',
                  'Main',
                  'version'   ]

ext_modules=[Extension("_hint",["src/asci.c",
                                       "src/debug.c",
                                       "src/hint.c",
                                       "src/masterfile.c",
                                       "src/base.c",
                                       "src/extract.c",
                                       "src/gtraffic.c",
                                       "src/hint_wrap.c",
                                       "src/precompute.c",
                                       ])]

data_files=[(".",['ttraffic.levels',
                  'CHANGELOG',
                  'AUTHORS',
                  'COPYING',
		  'README',
		  'INSTALL']),
	    ('ICNS',['ICNS/carNred.ico',
                     'ICNS/carNred16x16.ico',
                     'ICNS/carNred32x32.ico',
                     'ICNS/carNred64x64.png']),
	    ('DOCS',glob.glob('DOCS/*.htm')+glob.glob('DOCS/*.png')),
            ('MUSIC',["MUSIC/Ranger_Song.s3m",
                      "MUSIC/Ranger_Song.COPYRIGHT"])
	     ]+theme_files()\
              +main_command()\
              +windows_installer()\
              +menu_entry()

long_description="""\
PyTraffic is a Python version of the board game Rush Hour
created by Binary Arts Coporation. The goal is to remove the red
car out of the grid through the slot on the right. To do this you have to
slide the other cars out of the way.

PyTraffic comes with about 19.000 puzzles ranging from intermediate to
expert.
"""

setup_kw={'options': options,
          'name' : "pytraffic",
          'version' : version.version,
          'description' : "A Python simulation of the Game Rush Hour.",
          'author' : "Michel Van den Bergh",
          'author_email' : "michel.vandenbergh@uhasselt.be",
          'url' : "http://alpha.uhasselt.be/Research/Algebra",
          'long_description' : long_description,  
          'py_modules' : py_modules,
          'ext_modules' : ext_modules,
          'data_files' :data_files
          }

if py2exe_present:
    setup_kw['windows']=[{"script" : "WinMain.pyw",
    		          "icon_resources":[(1,"ICNS/carNred.ico")]}]

apply(setup,[],setup_kw)

# We remove our generated files. Otherwise the user may end up
# with root owned files in the directory (after an install as root).
if os.name=='posix':
    os.remove('pytraffic')
    os.remove('pytraffic.desktop')










